@@ -188,6 +188,10 @@ It is also possible that the OS sound setup is incorrect.
         return module
     def practise_lesson_id(self, lesson_id):
         module = self._practise_lesson_id(lesson_id)
+        if not self.m_teachers[module].m_P:
+            for n in self.m_ui.box_dict[module].action_area.get_children():
+                n.set_sensitive(False)
+            return
         self.m_ui.box_dict[module].on_start_practise()
         self.m_ui.m_history.add("solfege:/%s" % lesson_id)
         return module
