@@ -238,10 +238,8 @@ def del_key(key):
     section, k = split(key)
     #FIXME watches
     if section not in data:
-        print >> sys.stderr, "cfg.del_key: section does not exist"
         return
     if k not in data[section]:
-        print >> sys.stderr, "cfg.del_key: section '%s' does not have key '%s'" % (section, k)
         return
     del data[section][k]
     if not data[section]:
