@@ -16,8 +16,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os
+import sys
 
-def get_home_dir():
+def _get_home_dir():
     ''' Try to find user's home directory, otherwise return current directory.'''
     try:
         path1=os.path.expanduser("~")
@@ -41,3 +42,14 @@ def get_home_dir():
     else: return path1
 
 
+def get_home_dir():
+    if sys.platform == 'win32':
+        enc = sys.getfilesystemencoding()
+        if enc is None or enc == "":
+            enc = "iso-8859-1"
+        try:
+            return _get_home_dir().decode(enc)
+        except UnicodeDecodeError, e:
+            return _get_home_dir().decode("iso-8859-1")
+    return _get_home_dir()
+    
