@@ -19,10 +19,6 @@ from __future__ import division
 
 import pygtk
 pygtk.require("2.0")
-import gtk
-import i18n
-i18n.setup()
-
 import gtk
 import sys
 import mpd
