@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-copyright = "Copyright  1999-2005 Tom Cato Amundsen <tca@gnu.org>"
+copyright = "Copyright  1999-2006 Tom Cato Amundsen <tca@gnu.org>"
 
 import sys
 import os
@@ -634,10 +634,13 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                    ['practise', 'config', 'statistics'].index(urlobj.action))
             else:
                 self.box_dict[self.m_viewer].g_notebook.set_current_page(0)
-        if isinstance(self.box_dict[module].m_t, abstract.LessonbasedTeacher):
-            self.set_title("Solfege - " + self.box_dict[module].m_t.m_P.header.title)
+        if self.box_dict[module].m_t.m_P:
+            if isinstance(self.box_dict[module].m_t, abstract.LessonbasedTeacher):
+                self.set_title("Solfege - " + self.box_dict[module].m_t.m_P.header.title)
+            else:
+                self.set_title("Solfege - " + self.box_dict[module].m_t.exercise_data['name'].replace("_", ""))
         else:
-            self.set_title("Solfege - " + self.box_dict[module].m_t.exercise_data['name'].replace("_", ""))
+            self.set_title("Solfege")
         #self.m_history.add(urlobj.href)
         #self.show_help_on_current()
     def _show_docviewer(self):
