@@ -175,13 +175,19 @@ class RhythmViewer(gtk.Frame):
         assert len(self.m_data) <= self.m_num_beats
         if len(self.g_box.get_children()) >= self.m_num_beats:
             self.g_box.get_children()[self.m_num_beats-1].destroy()
+        vbox = gtk.VBox()
+        vbox.show()
         im = create_rhythm_image(RHYTHMS[i])
-        self.g_box.pack_start(im, False)
-        self.g_box.reorder_child(im, len(self.m_data))
+        vbox.pack_start(im)
+        vbox.pack_start(create_png_image('rhythm-wrong'), False, False)
+        vbox.get_children()[-1].hide()
+        self.g_box.pack_start(vbox, False)
+        self.g_box.reorder_child(vbox, len(self.m_data))
         self.m_data.append(i)
     def backspace(self):
         if len(self.m_data) > 0:
             if self.g_face:
+                self.g_box.get_children()[-2].destroy()
                 self.g_face.destroy()
                 self.g_face = None
             self.g_box.get_children()[len(self.m_data)-1].destroy()
@@ -192,13 +198,7 @@ class RhythmViewer(gtk.Frame):
         Mark the rhythm elements that was wrong by putting the content of
         graphics/rhythm-wrong.png (normally a red line) under the element.
         """
-        box = gtk.VBox()
-        r = self.g_box.get_children()[idx]
-        self.g_box.get_children()[idx].reparent(box)
-        box.pack_start(create_png_image('rhythm-wrong'), False, False)
-        self.g_box.pack_start(box, False)
-        self.g_box.reorder_child(box, idx)
-        box.show_all()
+        self.g_box.get_children()[idx].get_children()[1].show()
     def len(self):
         "return the number of rhythm elements currently viewed"
         return len(self.m_data)
