@@ -242,8 +242,6 @@ class LessonStatistics(AbstractStatistics):
     def lessonfile_changed(self, new_collection, new_file):
         if not new_file:
             return
-        if self.m_cur_file and self.m_session_stat != {}:
-            self.save_data()
 
         self.m_session_stat = {}
         self.m_today_stat = {}
